@@ -131,15 +131,35 @@ class MailingList(RESTObject):
         url = 'lists/{0}/held'.format(self.fqdn_listname)
         return Page(self._connection, url, HeldMessage, count, page)
 
+    def get_held_count(self):
+        """Get a count of held messages."""
+        response, json = self._connection.call(
+            'lists/{}/held/count'.format(self.fqdn_listname), None, 'GET')
+        return json['count']
+
     def get_held_message(self, held_id):
         url = 'lists/{0}/held/{1}'.format(self.fqdn_listname, held_id)
         return HeldMessage(self._connection, url)
 
     @property
     def requests(self):
-        """Return a list of dicts with subscription requests."""
-        response, content = self._connection.call(
-            'lists/{0}/requests'.format(self.fqdn_listname), None, 'GET')
+        """See :meth:`get_requests`."""
+        return self.get_requests()
+
+    def get_requests(self, token_owner=None):
+        """Return a list of dicts with subscription requests.
+
+        This is the new API for requests which allows filtering via
+        `token_owner` since it isn't possible to do so via the property
+        requests.
+
+        :param token_owner: Who owns the pending requests?  Should be one in
+            'no_one', 'moderator' and 'subscriber'.
+        """
+        url = 'lists/{0}/requests'.format(self.fqdn_listname)
+        if token_owner:
+            url += '?token_owner={}'.format(token_owner)
+        response, content = self._connection.call(url, None, 'GET')
         if 'entries' not in content:
             return []
         else:
@@ -147,12 +167,39 @@ class MailingList(RESTObject):
             for entry in content['entries']:
                 request = dict(email=entry['email'],
                                token=entry['token'],
+                               display_name=entry['display_name'],
                                token_owner=entry['token_owner'],
                                list_id=entry['list_id'],
                                request_date=entry['when'])
                 entries.append(request)
         return entries
 
+    def get_requests_count(self, token_owner=None):
+        """Return a total count of pending subscription requests.
+
+        This should be a faster query when *all* the requests aren't needed and
+        only a count is needed to display on the badge in List's settings page.
+
+        :param token_owner: Who owns the pending requests?  Should be one in
+            'no_one', 'moderator' and 'subscriber'.
+        :returns: The count of pending requests.
+        """
+        url = 'lists/{}/requests/count'.format(self.fqdn_listname)
+        if token_owner:
+            url += '?token_owner={}'.format(token_owner)
+        response, json = self._connection.call(url)
+        return json['count']
+
+    def get_request(self, token):
+        """Get an individual pending request for the given token.
+
+        :param token: The token for the request.
+        :returns: The request dictionary.
+        """
+        url = 'lists/{}/requests/{}'.format(self.fqdn_listname, token)
+        response, json = self._connection.call(url)
+        return json
+
     @property
     def archivers(self):
         url = 'lists/{0}/archivers'.format(self.list_id)
@@ -309,19 +356,24 @@ class MailingList(RESTObject):
         return self._get_membership(email, 'nonmember')
 
     def subscribe(self, address, display_name=None, pre_verified=False,
-                  pre_confirmed=False, pre_approved=False):
+                  pre_confirmed=False, pre_approved=False, invitation=False,
+                  send_welcome_message=None):
         """Subscribe an email address to a mailing list.
 
         :param address: Email address to subscribe to the list.
         :type address: str
         :param display_name: The real name of the new member.
+        :type display_name: str
         :param pre_verified: True if the address has been verified.
         :type pre_verified: bool
         :param pre_confirmed: True if membership has been approved by the user.
         :type pre_confirmed: bool
         :param pre_approved: True if membership is moderator-approved.
         :type pre_approved: bool
-        :type display_name: str
+        :param invitation: True if this is an invitation to join the list.
+        :type invitation: bool
+        :param send_welcome_message: True if welcome message should be sent.
+        :type send_welcome_message: bool
         :return: A member proxy object.
         """
         data = dict(
@@ -336,12 +388,19 @@ class MailingList(RESTObject):
             data['pre_confirmed'] = True
         if pre_approved:
             data['pre_approved'] = True
+        if invitation:
+            data['invitation'] = True
+        # Even if it is False, we should send this value because it means we
+        # should suppress welcome message, so check for None value to skip the
+        # parameter.
+        if send_welcome_message is not None:
+            data['send_welcome_message'] = send_welcome_message
         response, content = self._connection.call('members', data)
         # If a member is not immediately subscribed (i.e. verificatoin,
         # confirmation or approval need), the response content is returned.
         if response.status_code == 202:
             return content
-        # I the subscription is executed immediately, a member object
+        # If the subscription is executed immediately, a member object
         # is returned.
         return Member(self._connection, response.headers.get('location'))
 
